==> haskell-hsopenssl-0.11.4.15-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hsopenssl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HsOpenSSL
version: 0.11.4.15
id: HsOpenSSL-0.11.4.15-8z8GACC5S7fK9Pbl8Fd56p
key: HsOpenSSL-0.11.4.15-8z8GACC5S7fK9Pbl8Fd56p
license: LicenseRef-PublicDomain
maintainer: Vladimir Shabanov <dev@vshabanov.com>
author: Adam Langley, Mikhail Vorozhtsov, PHO, Taru Karttunen
stability: stable
homepage: https://github.com/vshabanov/HsOpenSSL
synopsis: Partial OpenSSL binding for Haskell
description:
    .
    HsOpenSSL is an OpenSSL binding for Haskell. It can generate RSA
    and DSA keys, read and write PEM files, generate message digests,
    sign and verify messages, encrypt and decrypt messages. It has
    also some capabilities of creating SSL clients and servers.
    .
    This package is in production use by a number of Haskell based
    systems and stable. You may also be interested in the @tls@ package,
    <http://hackage.haskell.org/package/tls>, which is a pure Haskell
    implementation of SSL.
    .
category: Cryptography
abi: 92147b2b10c0770f91ce4cd80241c1a4
exposed: True
exposed-modules:
    OpenSSL OpenSSL.BN OpenSSL.Cipher OpenSSL.DER OpenSSL.DH
    OpenSSL.DSA OpenSSL.EVP.Base64 OpenSSL.EVP.Cipher
    OpenSSL.EVP.Digest OpenSSL.EVP.Internal OpenSSL.EVP.Open
    OpenSSL.EVP.PKey OpenSSL.EVP.Seal OpenSSL.EVP.Sign
    OpenSSL.EVP.Verify OpenSSL.PEM OpenSSL.PKCS7 OpenSSL.RSA
    OpenSSL.Random OpenSSL.Session OpenSSL.X509 OpenSSL.X509.Request
    OpenSSL.X509.Revocation OpenSSL.X509.Store
hidden-modules: OpenSSL.ASN1 OpenSSL.BIO OpenSSL.ERR
                OpenSSL.Objects OpenSSL.SSL.Option OpenSSL.Stack OpenSSL.Utils
                OpenSSL.X509.Name OpenSSL.DH.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/HsOpenSSL-0.11.4.15
library-dirs: /usr/lib/ghc-8.6.1/site-local/HsOpenSSL-0.11.4.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/HsOpenSSL-0.11.4.15
hs-libraries: HSHsOpenSSL-0.11.4.15-8z8GACC5S7fK9Pbl8Fd56p
extra-libraries:
    ssl crypto
includes:
    openssl/asn1.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    network-2.7.0.2-11unSY69gPCAmgeVCL0SxR time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-hsopenssl/html/HsOpenSSL.haddock
haddock-html: /usr/share/doc/haskell-hsopenssl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsopenssl-0.11.4.15-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hsopenssl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HsOpenSSL
version: 0.11.4.15
id: HsOpenSSL-0.11.4.15-4CEipYhEdLnCT2cqPuCL5G
key: HsOpenSSL-0.11.4.15-4CEipYhEdLnCT2cqPuCL5G
license: LicenseRef-PublicDomain
maintainer: Vladimir Shabanov <dev@vshabanov.com>
author: Adam Langley, Mikhail Vorozhtsov, PHO, Taru Karttunen
stability: stable
homepage: https://github.com/vshabanov/HsOpenSSL
synopsis: Partial OpenSSL binding for Haskell
description:
    .
    HsOpenSSL is an OpenSSL binding for Haskell. It can generate RSA
    and DSA keys, read and write PEM files, generate message digests,
    sign and verify messages, encrypt and decrypt messages. It has
    also some capabilities of creating SSL clients and servers.
    .
    This package is in production use by a number of Haskell based
    systems and stable. You may also be interested in the @tls@ package,
    <http://hackage.haskell.org/package/tls>, which is a pure Haskell
    implementation of SSL.
    .
category: Cryptography
abi: c136e6b3fb0b8b5924ba15e44cb62911
exposed: True
exposed-modules:
    OpenSSL OpenSSL.BN OpenSSL.Cipher OpenSSL.DER OpenSSL.DH
    OpenSSL.DSA OpenSSL.EVP.Base64 OpenSSL.EVP.Cipher
    OpenSSL.EVP.Digest OpenSSL.EVP.Internal OpenSSL.EVP.Open
    OpenSSL.EVP.PKey OpenSSL.EVP.Seal OpenSSL.EVP.Sign
    OpenSSL.EVP.Verify OpenSSL.PEM OpenSSL.PKCS7 OpenSSL.RSA
    OpenSSL.Random OpenSSL.Session OpenSSL.X509 OpenSSL.X509.Request
    OpenSSL.X509.Revocation OpenSSL.X509.Store
hidden-modules: OpenSSL.ASN1 OpenSSL.BIO OpenSSL.ERR
                OpenSSL.Objects OpenSSL.SSL.Option OpenSSL.Stack OpenSSL.Utils
                OpenSSL.X509.Name OpenSSL.DH.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/HsOpenSSL-0.11.4.15
library-dirs: /usr/lib/ghc-8.6.1/site-local/HsOpenSSL-0.11.4.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/HsOpenSSL-0.11.4.15
hs-libraries: HSHsOpenSSL-0.11.4.15-4CEipYhEdLnCT2cqPuCL5G
extra-libraries:
    ssl crypto
includes:
    openssl/asn1.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    network-2.7.0.2-Fxn7IKbIXjq1GwNvEyamvn time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-hsopenssl/html/HsOpenSSL.haddock
haddock-html: /usr/share/doc/haskell-hsopenssl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
